##############################################################################
#
# Copyright (c) 2001, 2002, 2003 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################

# allows integration of archive files into Zope and access the contents of them
# like objects in a folder by Joachim Bauch
from Acquisition import aq_parent, aq_chain
from AccessControl import ClassSecurityInfo
from OFS.Image import Image, File, getImageInfo
from DateTime import DateTime

class ArchiveFile(File):
    
    meta_type = 'ArchiveFile'

    def __init__(self, id, properties, contentType):
        File.__init__(self, id, '', '', content_type=contentType)
        self.id = id
        self.properties = properties
        self.bobobase_modification_time = DateTime(properties['file_date'][0], properties['file_date'][1], properties['file_date'][2],
            properties['file_date'][3], properties['file_date'][4], properties['file_date'][5])
        self.data = None
        self.size = properties['file_size']

    def update_data(self, data, content_type=None, size=None):
        if aq_parent(self):
            aq_parent(self).setFile(self.id, data)
        self.data = data
        if content_type: self.content_type = content_type
        if size: self.size = size
        else: self.size = len(data)

    def get_properties(self):
        return self.size

    def getData(self):
        if self.data is None:
            self.data = aq_parent(self).getFile(self.id)
        return self.data

    def __str__(self): return str(self.getData())

    def index_html(self, REQUEST, RESPONSE):
        """
        The default view of the contents of a File or Image.

        Returns the contents of the file or image.  Also, sets the
        Content-Type HTTP header to the objects content type.
        """
        self.getData()
        return File.index_html(self, REQUEST, RESPONSE)

class ArchiveImage(Image, ArchiveFile):

    meta_type = 'ArchiveImage'

    def __init__(self, id, properties, contentType, data=None):
        ArchiveFile.__init__(self, id, properties, contentType)
        if data:
            self._parseImage(data)

    def _parseImage(self, data):
        ct, width, height = getImageInfo(data)
        if ct:
            self.content_type = ct
        if width >= 0 and height >= 0:
            self.width = width
            self.height = height

    def update_data(self, data, content_type=None, size=None):
        ArchiveFile.update_data(self, data, content_type=content_type, size=size)
        self._parseImage(data)

    get_properties = ArchiveFile.get_properties
    getData = ArchiveFile.getData
    __str__ = ArchiveFile.__str__
    index_html = ArchiveFile.index_html
